@@ -5,7 +5,7 @@ use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v2.0.0';
+our $VERSION = 'v2.0.1';
 
 use Scalar::Util qw( weaken );
 
@@ -195,6 +195,8 @@ __END__
 
 =encoding utf8
 
+=for stopwords ip EREQINEOF EREQINBUFLIMIT EINBUFLIMIT
+
 =head1 NAME
 
 IO::Stream - ease non-blocking I/O streams based on EV
@@ -202,7 +204,7 @@ IO::Stream - ease non-blocking I/O streams based on EV
 
 =head1 VERSION
 
-This document describes IO::Stream version v2.0.0
+This document describes IO::Stream version v2.0.1
 
 
 =head1 SYNOPSIS
@@ -295,10 +297,10 @@ compatibility.
 =head1 OVERVIEW
 
 You can create IO::Stream object using any "stream" fh
-(file, tty, UNIX socket, TCP socket, pipe, FIFO).
-Or, if you need tcp socket, you can create IO::Stream object using host+port
+(file, TTY, UNIX socket, TCP socket, pipe, FIFO).
+Or, if you need TCP socket, you can create IO::Stream object using host+port
 instead of fh (in this case IO::Stream will do non-blocking host resolving,
-create tcp socket and do non-blocking connect).
+create TCP socket and do non-blocking connect).
 
 After you created IO::Stream object, it will handle read/write on this fh,
 and deliver only high-level events you asked for into your callback, where
@@ -310,13 +312,13 @@ IO::Stream object - you can even do sysread()/syswrite() (but there no
 reasons for you to do this anymore).
 
 B<IMPORTANT!> When you want to close this fh,
-B<you MUST use $stream-E<gt>close() method for closing fh> instead of
+B<you MUST use $io-E<gt>close() method for closing fh> instead of
 doing close($fh). This is because IO::Stream doesn't require from you to
-keep object returned by new(), and without call to $stream->close()
+keep object returned by new(), and without call to $io->close()
 IO::Stream object will continue to exists and may receive/generate some
 events, which is not what you expect after closing fh. Also, if you keep
 object returned by IO::Stream->new() somewhere in your variables, you
-should either undef all such variables after you called $stream->close(),
+should either undef all such variables after you called $io->close(),
 or you should use Scalar::Util::weaken() on these variables after storing
 IO::Stream object. (The same is applicable for all plugin objects too.)
 
@@ -363,7 +365,7 @@ written you should use SENT event, not OUT.
 =item SENT
 
 Generated when all data from {out_buf} was written. It's usual and safe to
-call $stream->close() on SENT event.
+call $io->close() on SENT event.
 
 =back
 
@@ -380,7 +382,7 @@ Current version doesn't allow you to change these timeouts.
 
 =head2 SERVER
 
-If you need to run tcp/unix-server socket, then you should handle that socket
+If you need to run TCP/UNIX-server socket, then you should handle that socket
 manually. But you can create IO::Stream object for accept()'ed socket:
 
     my ($host, $port) = ('0.0.0.0', 1234);
@@ -439,15 +441,15 @@ When some event arise which you're waited for, your callback will be
 called with 3 parameters: IO::Stream object, event mask, and error (if any):
 
     sub callback {
-        my ($stream, $e, $err) = @_;
+        my ($io, $e, $err) = @_;
     }
 
 
 =head1 METHODS
 
-=over
+=head2 new
 
-=item new(\%opt)
+    IO::Stream->new( \%opt );
 
 Create and return IO::Stream object. You may not keep returned object - you
 will get it in your callback (in first parameter) when some interesting
@@ -470,9 +472,10 @@ creating object.
         wait_for    => IN,
     });
 
-=item write()
+=head2 write
 
-=item write($data)
+    $io->write();
+    $io->write($data);
 
 Method write() B<MUST> be called after any modifications of {out_buf} field,
 to ensure data in {out_buf} will be written to {fh} as soon as it will be
@@ -487,18 +490,17 @@ after it return from write() into your callback.
 
 The write($data) is just a shortcut for:
 
-    $stream->{out_buf} .= $data;
-    $stream->write();
+    $io->{out_buf} .= $data;
+    $io->write();
 
-=item close()
+=head2 close
+
+    $io->close()
 
 Method close() will close {fh} and destroy IO::Stream object.
 See L<OVERVIEW> for more details.
 
 
-=back
-
-
 =head1 PUBLIC FIELDS
 
 If field marked *RO* that mean field is read-only and shouldn't be changed.
@@ -524,7 +526,7 @@ cases method named {method} will be called. Field {method} should be string.
 Bitmask of events interesting for user. Can be changed at any time.
 For example:
 
-    $stream->{wait_for} = RESOLVED|CONNECTED|IN|EOF|OUT|SENT;
+    $io->{wait_for} = RESOLVED|CONNECTED|IN|EOF|OUT|SENT;
 
 When some data will be read from {fh}, {wait_for} must contain IN and/or EOF,
 or error EREQINEOF will be generated. So, it's better to always have
@@ -543,7 +545,7 @@ by new() (when user provided {host}+{port} instead).
 =item port *RO*
 
 If user doesn't provide {fh} to new(), he should provide {host} and {port}
-instead. This way new() will create new tcp socket in {fh} and resolve
+instead. This way new() will create new TCP socket in {fh} and resolve
 {host} and connect this {fh} to resolved {ip} and {port}. Both resolving
 and connecting happens in non-blocking way, and will result in delivering
 RESOLVED and CONNECTED events into user callback (if user {wait_for} these
@@ -613,7 +615,7 @@ and later access these plugins.
 This field is somewhat special, because when you call new() you should
 set plugin to ARRAY ref, but in IO::Stream object {plugin} is HASH ref:
 
-    my $stream = IO::Stream->new({
+    my $io = IO::Stream->new({
         host        => 'www.google.com',
         port        => 443,
         cb          => \&google,
@@ -634,7 +636,7 @@ set plugin to ARRAY ref, but in IO::Stream object {plugin} is HASH ref:
     });
 
     # access the "proxy" plugin:
-    $stream->{plugin}{proxy};
+    $io->{plugin}{proxy};
 
 This is because when calling new() it's important to keep plugins in order,
 but later it's easier to access them using names.
@@ -669,9 +671,9 @@ type is not supported (directory handle), or fh is not file handle at all.
 
 You can't have more than one IO::Stream object for same fh.
 
-IO::Stream keep all objects created by new() until $stream->close() will be
+IO::Stream keep all objects created by new() until $io->close() will be
 called. Probably you've closed fh in some way without calling
-$stream->close(), then new fh was created with same file descriptor
+$io->close(), then new fh was created with same file descriptor
 number, and you've tried to create IO::Stream object using new fh.
 
 =back
@@ -734,7 +736,7 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2008-2016 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2008- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
