@@ -1,6 +1,6 @@
-use open qw( :std :utf8 );
 use Test::More;
 use Test::Exception;
+use Test::Differences;
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -68,7 +68,7 @@ sub checkpoint {
     if (ref $CheckPoint[0] eq 'HASH') {
 	croak("No alternative to match: $func @_");
     }
-    is_deeply([$func, @_], shift @CheckPoint, shift @CheckPoint);
+    eq_or_diff([$func, @_], shift @CheckPoint, shift @CheckPoint);
     return;
 }
 
@@ -101,6 +101,12 @@ sub nonblocking {
     return;
 }
 
+sub sockport {
+    my ($sock) = @_;
+    my ($port) = sockaddr_in(getsockname $sock);
+    return $port;
+}
+
 sub tcp_server {
     my ($host, $port) = @_;
     socket my $sock, AF_INET, SOCK_STREAM, 0        or croak qq{socket: $!};
